@@ -29,7 +29,34 @@
 
 
  class Adif{
+/*
+This class is really not independant FROM the GUI as the numbers to codify the
+MODE and BANDS depend on the position of the band in the COMBO-box.
+The BAND is being changed... the mode should be changed!
 
+Please follow this table of equivalences:
+
+BAND FREQS (MHz) GUI
+160M 1,2  0
+80M  3,4  1
+60M  5  2
+40M  7  3
+30M  10  4
+20M  14  5
+17M  18  6
+15M  21  7
+12M  24  8
+10M  28,29  9
+6M   50...54  10
+2M   144...148 11
+125CM  219...225 12
+70CM  420...450 13
+33CM  902...928 14
+23CM  1240...1300 15
+13CM  2300...2450 16
+*/
+
+     
 public:
 
   Adif();
@@ -43,9 +70,15 @@ public:
   bool isHF(const QString& tfreq);   // Input is the same as in freq2Int
   bool isVHF(const QString& tfreq);  // Input is the same as in freq2Int
   bool isWARC(const QString& tfreq);  // Input is the same as in freq2Int
+  
+  // The next functions are just to adapt the specific KLog GUI to this general ADIF class
+  int klog2Adif(int klogN);
+  int adif2Klog(int adifN);
+
 private:
 
   QString sAux;
+  int iInt;
 
 };
 
