@@ -50,7 +50,8 @@ AwardWAZ::AwardWAZ(){
 }
 
 
-AwardWAZ::~AwardWAZ(){}
+AwardWAZ::~AwardWAZ(){
+}
 
 void AwardWAZ::clear(){
   i = 0;
@@ -211,7 +212,6 @@ int AwardWAZ::howManyWorkedMode(const int tmode){
 }
 
 int AwardWAZ::howManyWorked(){
-
   iAux = 0;
   for (i = 1; i < ZONES; i++){
      if (wazW[i])
@@ -311,7 +311,6 @@ int AwardWAZ::howManyConfirmedMode(const int tmode){
 }
 
 int AwardWAZ::howManyConfirmed(){
-
   iAux = 0;
   for (i = 1; i < ZONES; i++){
      if (wazC[i])
