@@ -25,9 +25,11 @@
 
 #include <klocale.h>
 //#include <kdebug.h>
+//#include <ostream.h>
 #include "entity.h"
 
-Entity::Entity(){}
+Entity::Entity(){
+}
 
 Entity::Entity (const int tnumb, const QString& tentity, const QString& tpfx, const int tcqz, const long tlon, const long tlat, const QString& tcontinent, const int tituz,  const int ttimeZone){
 
@@ -55,46 +57,84 @@ Entity::Entity (const int tnumb, const QString& tentity, const QString& tpfx, co
   ituz = tituz;
 }
 */
-Entity::~Entity(){}
+Entity::~Entity(){
+}
 
 void Entity::setEntity(const QString &tentity){
   entity = tentity;
 }
 
-QString Entity::getEntity() const{return entity;}
+QString Entity::getEntity() const{
+    return entity;
+}
 
 void Entity::setPfx(const QString &tpfx){
-  pfx = tpfx;
+    pfx = tpfx;
 }
 
-QString Entity::getPfx() const{return pfx;}
+QString Entity::getPfx() const{
+    return pfx;
+}
 
-void Entity::setNumb(int tnumb){numb = tnumb;}
-int Entity::getNumb() const{return numb;}
+void Entity::setNumb(int tnumb){
+    numb = tnumb;
+}
 
-void Entity::setCqz (int tcqz){cqz = tcqz;}
-int Entity::getCqz() const{return cqz;}
+int Entity::getNumb() const{
+    return numb;
+}
 
-void Entity::setLon(double tlon){lon = tlon;}
-double  Entity::getLon() const{return lon;}
+void Entity::setCqz (int tcqz){
+    cqz = tcqz;
+}
 
-void Entity::setLat(double tlat){lat = tlat;}
-double Entity::getLat() const{return  lat;}
+int Entity::getCqz() const{
+    return cqz;
+}
 
-void Entity::setItuz(int tituz){ituz = tituz;}
-int Entity::getItuz() const{return ituz;}
+void Entity::setLon(double tlon){
+    lon = tlon;
+}
+
+double  Entity::getLon() const{
+    return lon;
+}
+
+void Entity::setLat(double tlat){
+    lat = tlat;
+}
+
+double Entity::getLat() const{
+    return  lat;
+}
+
+void Entity::setItuz(int tituz){
+    ituz = tituz;
+}
+
+int Entity::getItuz() const{
+    return ituz;
+}
 
 void Entity::setContinent(const QString &tcontinent){
-  continent = tcontinent;
+    continent = tcontinent;
 }
 
-QString Entity::getContinent() const{return continent;}
+QString Entity::getContinent() const{
+    return continent;
+}
 
 void Entity::addPrefix(const QString tprx){
   prefixes.append(tprx);
 }
 
-void Entity::setTimeZone(int ttimeZone){timeZone = ttimeZone;}
-int Entity::getTimeZone() const{return timeZone;}
+void Entity::setTimeZone(int ttimeZone){
+    timeZone = ttimeZone;
+}
+
+int Entity::getTimeZone() const{
+    return timeZone;
+}
+
 
 
