@@ -126,7 +126,7 @@ class Klog : public klogui {
   void slotQSLRecSent();  
   void slotQsoDelete();
 //  slotDeleteQso();
-  void slotQrzSearchChanged();
+//  void slotQrzSearchChanged();
   void slotCancelSearchButton();
   void slotSearchButton();
   void slotQrzChanged();
@@ -223,12 +223,13 @@ class Klog : public klogui {
     void showAwardsNumbers(); // Shows how many worked, confirmed, ...
     void showDistancesAndBeam(const int dist, const int beam); // Shows distance and beam
     void completeAllQSOsFromLog();
+    void KloggetAllTheCallsFromLog(); // To be run once after the log is read from the disk.
     void fillEntityBandState(const int enti);
     void sortLog(); //To order by date the log and produce OLog
     void showIfPreviouslyWorked(); // Uses previousQso and workedCall
     void addToPreviouslyWorked(); // Uses previousQso and workedCall    
     void completeThePreviouslyWorked();
-
+    void getAllTheCallsFromLog();
 
 
 
@@ -333,6 +334,7 @@ class Klog : public klogui {
     bool dxClusterWXANNounces;
     bool dxClusterWCYANNounces;
     bool dxClusterANNounces;
+    bool dxClusterConfirmedSpots;    
 //    void paintCell( QPainter *p, const QColorGroup &cg, int column, int width, int alignment );
 //  virtual void paintCell( QPainter *p, const QColorGroup &cg, int column, int width, int align );
     
