@@ -24,6 +24,7 @@
  *****************************************************************************/
 #include <klocale.h>
 //#include <kdebug.h>
+//#include <ostream.h>
 #include "locator.h"
 
 
@@ -33,7 +34,8 @@ Locator::Locator(){
   isec = 0;
 }
 
-Locator::~Locator(){}
+Locator::~Locator(){
+}
 
 bool Locator::isValidLocator(const QString& tlocator){
 /* -------------- Subroutine -----------------------
@@ -84,7 +86,6 @@ double Locator::getLon(const QString& tlocator){
 }
 
 int Locator::getBeam(const double lon1, const double lat1, const double lon2, const double lat2){
-
   double lon_a,lat_a,lon_b,lat_b, bearing;
   lon_a=lon1*PI/180;   // Convert degrees to radians
   lat_a=lat1*PI/180;
@@ -141,13 +142,11 @@ int Locator::getDistanceKilometres(const double lon1, const double lat1, const d
 }
 
 int Locator::getDistanceMilles(const double lon1, const double lat1, const double lon2, const double lat2){
-
   return  (int)(getDistanceKilometres(lon1, lat1, lon2, lat2)/1.609) ;
 
 }
 
 QString Locator::getLocator(const double lon1, const double lat1) const{
-
 /* -------------- Subroutine -----------------------
    Calculate locator from longitude and latitude
    Input : lon = Longitude in decimal degrees (+ = West;  - = East).
@@ -185,7 +184,6 @@ return locat;
 }
 
 void Locator::degTodms(const double deg){
-
   double temp;
   double ddeg;
   ddeg = 0;
@@ -198,5 +196,5 @@ void Locator::degTodms(const double deg){
 }
 
 double Locator::dmsTodeg (int deg, int min, int sec){
-  return (double)deg + (double)min/60.0 + (double)sec/3600.0;
+    return (double)deg + (double)min/60.0 + (double)sec/3600.0;
 }
