@@ -24,10 +24,12 @@
  *****************************************************************************/
 #include <klocale.h>
 //#include <kdebug.h>
+//#include <ostream.h>
 #include "qso.h"
 
 
-Qso::Qso(){}
+Qso::Qso(){
+}
 
 Qso::Qso(const QString& tqrz, int tnumb, QString& tmode){
   qrz = tqrz;
@@ -41,7 +43,6 @@ Qso::Qso(const QString& tqrz, int tnumb, QString& tmode){
 
 
 Qso::Qso(const int tnumb, const QString& tqrz, const int trstrx, const int trsttx, int tband, const QString& tmode, const int tpower){
-
     qrz = tqrz;
     numb = tnumb;
     mode = tmode;
@@ -74,7 +75,6 @@ Qso::Qso(const int tnumb, const QDateTime tdateTime, const QString& tqrz, const
 }      
 
 Qso::Qso (const int tnumb, const QDateTime& tdateTime, const QString& tqrz, const int trstrx, const int trsttx, int tband, const QString& tmode, const int tpower, const QDate& tqslSen,  const QDate& tqslRec, const QString& tcomment){
-
   qrz = tqrz;
   numb = tnumb;
   dateTime = tdateTime;
@@ -92,7 +92,8 @@ Qso::Qso (const int tnumb, const QDateTime& tdateTime, const QString& tqrz, cons
 }
 
 
-Qso::~Qso(){}
+Qso::~Qso(){
+}
 
 void Qso::setQrz(const QString &tqrz ){
   qrz = tqrz;
@@ -107,49 +108,59 @@ void Qso::setNumb (int tnumb){
   numb = tnumb  ;
 }
 
-int Qso::getNumb() const{return numb;}
+int Qso::getNumb() const{
+    return numb;}
 
-void Qso::setDateTime(QDateTime tdateTime){dateTime = tdateTime;}
+void Qso::setDateTime(QDateTime tdateTime){
+    dateTime = tdateTime;}
 QDateTime Qso::getDateTime() const{return dateTime;}
 
 void Qso::setRstrx(int trstrx){
-  rstrx = trstrx;  
+    rstrx = trstrx;  
 }
 
-int Qso::getRstrx() const{return rstrx;}
+int Qso::getRstrx() const{
+    return rstrx;}
 
 void Qso::setRsttx(int trsttx){
-  rsttx = trsttx;  
+    rsttx = trsttx;  
 }
 
-int Qso::getRsttx() const{return rsttx;}
+int Qso::getRsttx() const{
+    return rsttx;}
 
 void Qso::setBand (const QString& tband){
- band = tband;  
+    band = tband;  
 }
 
-QString Qso::getBand() const{return band;}
+QString Qso::getBand() const{
+    return band;}
 
-void Qso::setFreq (const QString& tfreq){freq = tfreq;}
+void Qso::setFreq (const QString& tfreq){
+    freq = tfreq;}
 
-QString Qso::getFreq() const{return freq;}
+QString Qso::getFreq() const{
+    return freq;}
   
 void Qso::setMode(const QString& tmode){
-  mode = tmode;
+    mode = tmode;
 }
 
-QString Qso::getMode() const{return mode;}
+QString Qso::getMode() const{
+    return mode;}
 
 void Qso::setPower(const QString& tpower){
-  power = tpower;  
+    power = tpower;  
 }
 
-QString Qso::getPower() const{return power;}
+QString Qso::getPower() const{
+    return power;}
 
 void Qso::setComment(const QString &tcomment){
-  comment = tcomment;
+    comment = tcomment;
 }
-QString Qso::getComment()const{return comment;}
+QString Qso::getComment()const{
+    return comment;}
 
 void Qso::setQslSenDateOn(QDate tdate){
   qslSen = tdate;
@@ -214,18 +225,20 @@ void Qso::setQslManager(const QString &tqrz){
 
 } 
 
-QString Qso::getQslManager() const {return manager;}
+QString Qso::getQslManager() const {
+    return manager;}
 
 void Qso::setQslInfo(const QString &tqslInfo){
   qslInfo = tqslInfo;
 
 }
 
-QString Qso::getQslInfo()const{return qslInfo;}
+QString Qso::getQslInfo()const{
+    return qslInfo;}
 
 
 void Qso::setLocator(const QString &tgridSquare ){
-  gridSquare = tgridSquare;
+    gridSquare = tgridSquare;
 }
 
 QString Qso::getLocator() const {
@@ -236,7 +249,8 @@ void Qso::setIota(const QString &tiota){
   iota = tiota;
 }
 
-QString Qso::getIota() const{return iota;}
+QString Qso::getIota() const{
+    return iota;}
 
 QString Qso::getIotaContinent() const{
   return iota.section('-',0,0);
@@ -263,7 +277,7 @@ QString Qso::getQth() const{
 }
 
 void Qso::setOperator(const QString &toperator){
-  callUsed = toperator;
+    callUsed = toperator;
 }
 
 QString Qso::getOperator() const{
