@@ -25,6 +25,7 @@
 
 #include <klocale.h>
 //#include <kdebug.h>
+//#include <ostream.h>
 #include "setup.h"
 
 
@@ -45,7 +46,6 @@ Setup::Setup(QWidget *parent, const char *name) : setupui(parent, name)
 
 Setup::~Setup()
 {
-
 }
 
 
@@ -134,13 +134,18 @@ void Setup::readConf(){
           }else if ((theData.upper() == "FALSE")){
             setupui::WXcheckBox->setChecked(false);
           }
+        }else if (adifTab == "DXCLUSTERCONFIRMEDANNOUNCES"){
+          if (theData.upper() == "TRUE"){
+            setupui::confirmedcheckBox->setChecked(true);
+          }else if ((theData.upper() == "FALSE")){
+            setupui::confirmedcheckBox->setChecked(false);
+          }
         }else if (adifTab == "DXCLUSTERWCYANNOUNCES"){
           if (theData.upper() == "TRUE"){
             setupui::WCYcheckBox->setChecked(true);
           }else if ((theData.upper() == "FALSE")){
             setupui::WCYcheckBox->setChecked(false);
-          }
-   
+          }   
         }else if (adifTab == "REALTIMELOG"){
           if (theData.upper() == "TRUE"){
             setupui::realTimeLogCheckBox->setChecked(true);
@@ -249,8 +254,13 @@ if (setupui::WCYcheckBox->isChecked()){
     }else{
       tmp="false";
     }
-    stream << "dxclusterwcyannounces=" + tmp << endl;    
-    
+    stream << "dxclusterwcyannounces=" + tmp << endl;      
+if (setupui::confirmedcheckBox->isChecked()){
+      tmp="true";
+    }else{
+      tmp="false";
+    }
+    stream << "dxclusterconfirmedannounces=" + tmp << endl;          
     if (setupui::realTimeLogCheckBox->isChecked()){
       tmp="true";
     }else{
